Coverage for vcr.persisters.filesystem: 38%

# Coverage for vcr.persisters.filesystem : 38%

## 8 statements 3 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 | import os class FilesystemPersister(object): @classmethod def write(cls, cassette_path, data): dirname, filename = os.path.split(cassette_path) if dirname and not os.path.exists(dirname): os.makedirs(dirname) with open(cassette_path, 'w') as f: f.write(data)